@@ -1,4 +1,5 @@
 import yaml
+import os,shutil
 from .db2quilt import cvm2pkg
 from .cvm import CVM
 from .cqml12 import ensure_v02
@@ -12,6 +13,10 @@ class CQML(CVM):
         pkgs = {cqml:pkg_cqml(cqml, self.spark) for cqml in runs}
         return pkgs
 
+    def do_save(self, action):
+        pkg = cvm2pkg(cvm)
+        return pkg
+
 def upgrade_file(yaml_file):
     print("Upgrading "+yaml_file)
     with open(yaml_file) as data:
@@ -48,4 +53,12 @@ def pkg_cqml(name, spark, folder="pipes"):
     print("\npkg_cqml: "+name)
     cvm = exec_cqml(name, spark, folder)
     pkg = cvm2pkg(cvm)
-    return {'pkg': pkg, 'html': pkg.html, 'actions': cvm.actions}
+    return {'pkg': pkg, 'html': pkg.html,  'url': pkg.url, 'actions': cvm.actions}
+
+def pkg_all(spark, folder="pipes"):
+    files = os.listdir(folder)
+    keys = [os.path.splitext(file)[0] for file in files if file.endswith("ml")]
+    keys.sort()
+    print(keys)
+    pkgs = {key:pkg_cqml(key, spark, folder) for key in keys}
+    return pkgs
